package main

import (
	"fmt"
	"go.uber.org/zap"
	"log"
	"net/http"
	"wireguard-dashboard/config"
	"wireguard-dashboard/initialize"
	"wireguard-dashboard/route"
	"wireguard-dashboard/script"
)

func init() {
	initialize.Init() // 初始化
	if err := script.NewScript().Do(); err != nil {
		zap.S().Errorf("执行脚本错误: %v", err.Error())
	}
}

func main() {
	route.IncludeRouters(
		route.Captcha,
		route.UserApi,
	)
	handler := route.InitRouter()

	httpServe := http.Server{
		Addr:    fmt.Sprintf(":%d", config.Config.Http.Port),
		Handler: handler,
	}

	if err := httpServe.ListenAndServe(); err != nil {
		log.Panicf("启动http服务端失败: %v", err.Error())
	}
}
